<?php

namespace Litepie\Medium\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Litepie\Medium\Http\Requests\TargetGroupRequest;
use Litepie\Medium\Interfaces\TargetGroupRepositoryInterface;
use Litepie\Medium\Models\TargetGroup;
use Litepie\Medium\Forms\TargetGroup as Form;

/**
 * APIController  class for target_group.
 */
class TargetGroupAPIController extends BaseController
{

    /**
     * Initialize target_group resource controller.
     *
     * @param type TargetGroupRepositoryInterface $target_group
     *
     * @return null
     */
    public function __construct(TargetGroupRepositoryInterface $target_group)
    {
        parent::__construct();
        $this->repository = $target_group;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litepie\Medium\Repositories\Criteria\TargetGroupResourceCriteria::class);
    }

    /**
     * Display a list of target_group.
     *
     * @return Response
     */
    public function index(TargetGroupRequest $request)
    {
        return $this->repository
            ->setPresenter(\Litepie\Medium\Repositories\Presenter\TargetGroupPresenter::class)
            ->paginate();
    }

    /**
     * Display target_group.
     *
     * @param Request $request
     * @param Model   $target_group
     *
     * @return Response
     */
    public function show(TargetGroupRequest $request, TargetGroup $target_group)
    {
        return $target_group->setPresenter(\Litepie\Medium\Repositories\Presenter\TargetGroupListPresenter::class);
        ;
    }

    /**
     * Create new target_group.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(TargetGroupRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('medium::target_group.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('medium/target_group/' . $target_group->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('medium/target_group');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the target_group.
     *
     * @param Request $request
     * @param Model   $target_group
     *
     * @return Response
     */
    public function update(TargetGroupRequest $request, TargetGroup $target_group)
    {
        try {
            $data = $request->all();

            $target_group->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('medium::target_group.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('medium/target_group/' . $target_group->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('medium/target_group/' . $target_group->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the target_group.
     *
     * @param Model   $target_group
     *
     * @return Response
     */
    public function destroy(TargetGroupRequest $request, TargetGroup $target_group)
    {
        try {
            $target_group->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('medium::target_group.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('medium/target_group/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('medium/target_group/' . $target_group->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
