<?php

namespace Litepie\Medium\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Litepie\Medium\Interfaces\TargetGroupRepositoryInterface;

class TargetGroupPublicController extends BaseController
{
    // use TargetGroupWorkflow;

    /**
     * Constructor.
     *
     * @param type \Litepie\TargetGroup\Interfaces\TargetGroupRepositoryInterface $target_group
     *
     * @return type
     */
    public function __construct(TargetGroupRepositoryInterface $target_group)
    {
        $this->repository = $target_group;
        parent::__construct();
    }

    /**
     * Show target_group's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $target_groups = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->setMetaTitle(trans('medium::target_group.names'))
            ->view('medium::public.target_group.index')
            ->data(compact('target_groups'))
            ->output();
    }


    /**
     * Show target_group.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $target_group = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->setMetaTitle($target_group->name . trans('medium::target_group.name'))
            ->view('medium::public.target_group.show')
            ->data(compact('target_group'))
            ->output();
    }

}
