<?php

namespace Litepie\Medium\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litepie\Medium\Models\MediaDetailCategory;

class MediaDetailCategoryPolicy
{

    /**
     * Determine if the given user can view the media_detail_category.
     *
     * @param UserPolicy $user
     * @param MediaDetailCategory $media_detail_category
     *
     * @return bool
     */
    public function view(UserPolicy $user, MediaDetailCategory $media_detail_category)
    {
        if ($user->canDo('medium.media_detail_category.view') && $user->isAdmin()) {
            return true;
        }

        return $media_detail_category->user_id == user_id() && $media_detail_category->user_type == user_type();
    }

    /**
     * Determine if the given user can create a media_detail_category.
     *
     * @param UserPolicy $user
     * @param MediaDetailCategory $media_detail_category
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('medium.media_detail_category.create');
    }

    /**
     * Determine if the given user can update the given media_detail_category.
     *
     * @param UserPolicy $user
     * @param MediaDetailCategory $media_detail_category
     *
     * @return bool
     */
    public function update(UserPolicy $user, MediaDetailCategory $media_detail_category)
    {
        if ($user->canDo('medium.media_detail_category.edit') && $user->isAdmin()) {
            return true;
        }

        return $media_detail_category->user_id == user_id() && $media_detail_category->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given media_detail_category.
     *
     * @param UserPolicy $user
     * @param MediaDetailCategory $media_detail_category
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, MediaDetailCategory $media_detail_category)
    {
        return $media_detail_category->user_id == user_id() && $media_detail_category->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given media_detail_category.
     *
     * @param UserPolicy $user
     * @param MediaDetailCategory $media_detail_category
     *
     * @return bool
     */
    public function verify(UserPolicy $user, MediaDetailCategory $media_detail_category)
    {
        if ($user->canDo('medium.media_detail_category.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given media_detail_category.
     *
     * @param UserPolicy $user
     * @param MediaDetailCategory $media_detail_category
     *
     * @return bool
     */
    public function approve(UserPolicy $user, MediaDetailCategory $media_detail_category)
    {
        if ($user->canDo('medium.media_detail_category.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
