<?php

namespace Litepie\Medium\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litepie\Medium\Models\MediaTag;

class MediaTagPolicy
{

    /**
     * Determine if the given user can view the media_tag.
     *
     * @param UserPolicy $user
     * @param MediaTag $media_tag
     *
     * @return bool
     */
    public function view(UserPolicy $user, MediaTag $media_tag)
    {
        if ($user->canDo('medium.media_tag.view') && $user->isAdmin()) {
            return true;
        }

        return $media_tag->user_id == user_id() && $media_tag->user_type == user_type();
    }

    /**
     * Determine if the given user can create a media_tag.
     *
     * @param UserPolicy $user
     * @param MediaTag $media_tag
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('medium.media_tag.create');
    }

    /**
     * Determine if the given user can update the given media_tag.
     *
     * @param UserPolicy $user
     * @param MediaTag $media_tag
     *
     * @return bool
     */
    public function update(UserPolicy $user, MediaTag $media_tag)
    {
        if ($user->canDo('medium.media_tag.edit') && $user->isAdmin()) {
            return true;
        }

        return $media_tag->user_id == user_id() && $media_tag->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given media_tag.
     *
     * @param UserPolicy $user
     * @param MediaTag $media_tag
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, MediaTag $media_tag)
    {
        return $media_tag->user_id == user_id() && $media_tag->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given media_tag.
     *
     * @param UserPolicy $user
     * @param MediaTag $media_tag
     *
     * @return bool
     */
    public function verify(UserPolicy $user, MediaTag $media_tag)
    {
        if ($user->canDo('medium.media_tag.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given media_tag.
     *
     * @param UserPolicy $user
     * @param MediaTag $media_tag
     *
     * @return bool
     */
    public function approve(UserPolicy $user, MediaTag $media_tag)
    {
        if ($user->canDo('medium.media_tag.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
