<?php

namespace Litepie\Medium\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litepie\Medium\Models\MediaTopic;

class MediaTopicPolicy
{

    /**
     * Determine if the given user can view the media_topic.
     *
     * @param UserPolicy $user
     * @param MediaTopic $media_topic
     *
     * @return bool
     */
    public function view(UserPolicy $user, MediaTopic $media_topic)
    {
        if ($user->canDo('medium.media_topic.view') && $user->isAdmin()) {
            return true;
        }

        return $media_topic->user_id == user_id() && $media_topic->user_type == user_type();
    }

    /**
     * Determine if the given user can create a media_topic.
     *
     * @param UserPolicy $user
     * @param MediaTopic $media_topic
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('medium.media_topic.create');
    }

    /**
     * Determine if the given user can update the given media_topic.
     *
     * @param UserPolicy $user
     * @param MediaTopic $media_topic
     *
     * @return bool
     */
    public function update(UserPolicy $user, MediaTopic $media_topic)
    {
        if ($user->canDo('medium.media_topic.edit') && $user->isAdmin()) {
            return true;
        }

        return $media_topic->user_id == user_id() && $media_topic->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given media_topic.
     *
     * @param UserPolicy $user
     * @param MediaTopic $media_topic
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, MediaTopic $media_topic)
    {
        return $media_topic->user_id == user_id() && $media_topic->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given media_topic.
     *
     * @param UserPolicy $user
     * @param MediaTopic $media_topic
     *
     * @return bool
     */
    public function verify(UserPolicy $user, MediaTopic $media_topic)
    {
        if ($user->canDo('medium.media_topic.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given media_topic.
     *
     * @param UserPolicy $user
     * @param MediaTopic $media_topic
     *
     * @return bool
     */
    public function approve(UserPolicy $user, MediaTopic $media_topic)
    {
        if ($user->canDo('medium.media_topic.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
